==> tuia-news-center-api-0.0.44-xt30-20180705.043036-1-sources.jar: cn/com/duiba/tuia/news/center/dto/LimitPacketConditionDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by xiaotian on 2018/5/21.
 */
public class LimitPacketConditionDto implements Serializable{


    /**
     * 红包Id
     */
    private Long packetId;

    /**
     * 是否可开启下一个红包
     */
    private boolean canHaveNext;

    /**
     * 当前是第几个红包
     */
    private Integer packetSort = 0;

    /**
     * 是否是自己的红包
     */

    private boolean self;

    /**
     * 红包所属的用户的名称
     */
    private String name;

    /**
     * 用户头像
     */
    private String headImg;

    /**
     * 红包的用户Id
     */
    private Long userId;

    /**
     * 限时红包的最大金额
     */
    private Long packetAllCount;

    /**
     * 当前收集金额
     */
    private Long presentCount;

    /**
     * 红包剩余时间
     */
    private Long remainTime = 0L;

    /**
     * 帮戳人员的记录
     */
    private List<LimitOperateDto> operateDtos;

    /**
     * 帮拆口令
     */
    private String content;

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getPacketSort() {
        return packetSort;
    }

    public void setPacketSort(Integer packetSort) {
        this.packetSort = packetSort;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getPacketId() {
        return packetId;
    }

    public void setPacketId(Long packetId) {
        this.packetId = packetId;
    }

    public boolean isCanHaveNext() {
        return canHaveNext;
    }

    public void setCanHaveNext(boolean canHaveNext) {
        this.canHaveNext = canHaveNext;
    }

    public boolean isSelf() {
        return self;
    }

    public void setSelf(boolean self) {
        this.self = self;
    }

    public Long getPacketAllCount() {
        return packetAllCount;
    }

    public void setPacketAllCount(Long packetAllCount) {
        this.packetAllCount = packetAllCount;
    }

    public Long getPresentCount() {
        return presentCount;
    }

    public void setPresentCount(Long presentCount) {
        this.presentCount = presentCount;
    }

    public Long getRemainTime() {
        return remainTime;
    }

    public void setRemainTime(Long remainTime) {
        this.remainTime = remainTime;
    }

    public List<LimitOperateDto> getOperateDtos() {
        return operateDtos;
    }

    public void setOperateDtos(List<LimitOperateDto> operateDtos) {
        this.operateDtos = operateDtos;
    }
}

==> tuia-news-center-api-0.0.46-xt10-20180713.020550-1-sources.jar: cn/com/duiba/tuia/news/center/dto/LimitPacketConditionDto.java <==
package cn.com.duiba.tuia.news.center.dto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by xiaotian on 2018/5/21.
 */
public class LimitPacketConditionDto implements Serializable{


    /**
     * 红包Id
     */
    private Long packetId;

    /**
     * 是否可开启下一个红包
     */
    private boolean canHaveNext;

    /**
     * 当前是第几个红包
     */
    private Integer packetSort = 0;

    /**
     * 是否是自己的红包
     */

    private boolean self;

    /**
     * 红包所属的用户的名称
     */
    private String name;

    /**
     * 用户头像
     */
    private String headImg;

    /**
     * 红包的用户Id
     */
    private Long userId;

    /**
     * 限时红包的最大金额
     */
    private Long packetAllCount;

    /**
     * 当前收集金额
     */
    private Long presentCount;

    /**
     * 红包剩余时间
     */
    private Long remainTime = 0L;

    /**
     * 帮戳人员的记录
     */
    private List<LimitOperateDto> operateDtos;

    /**
     * 帮拆口令
     */
    private String content;

    /**
     * 剩下几个帮戳
     */
    private Long lastSort;

    public Long getLastSort() {
        return lastSort;
    }

    public void setLastSort(Long lastSort) {
        this.lastSort = lastSort;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public Integer getPacketSort() {
        return packetSort;
    }

    public void setPacketSort(Integer packetSort) {
        this.packetSort = packetSort;
    }

    public String getHeadImg() {
        return headImg;
    }

    public void setHeadImg(String headImg) {
        this.headImg = headImg;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public Long getPacketId() {
        return packetId;
    }

    public void setPacketId(Long packetId) {
        this.packetId = packetId;
    }

    public boolean isCanHaveNext() {
        return canHaveNext;
    }

    public void setCanHaveNext(boolean canHaveNext) {
        this.canHaveNext = canHaveNext;
    }

    public boolean isSelf() {
        return self;
    }

    public void setSelf(boolean self) {
        this.self = self;
    }

    public Long getPacketAllCount() {
        return packetAllCount;
    }

    public void setPacketAllCount(Long packetAllCount) {
        this.packetAllCount = packetAllCount;
    }

    public Long getPresentCount() {
        return presentCount;
    }

    public void setPresentCount(Long presentCount) {
        this.presentCount = presentCount;
    }

    public Long getRemainTime() {
        return remainTime;
    }

    public void setRemainTime(Long remainTime) {
        this.remainTime = remainTime;
    }

    public List<LimitOperateDto> getOperateDtos() {
        return operateDtos;
    }

    public void setOperateDtos(List<LimitOperateDto> operateDtos) {
        this.operateDtos = operateDtos;
    }
}
